#
# spec file for package open-lldp
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname liblldp_clif1
Name:           open-lldp
Summary:        Link Layer Discovery Protocol (LLDP) Agent
License:        GPL-2.0
Group:          System/Daemons
Version:        1.0.1+64.29d12e584af1
Release:        lp151.2.6.1
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libconfig-devel
BuildRequires:  libnl3-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
Url:            https://github.com/intel/openlldp
Source:         %{name}-v%{version}.tar.xz
BuildRoot:      %{_tmppath}/%{name}-v%{version}-build
Provides:       dcbd = %{version}
Obsoletes:      dcbd < %{version}
Provides:       lldpad = %{version}
Obsoletes:      lldpad < %{version}
BuildRequires:  systemd
%systemd_requires

%description
This package contains the Link Layer Discovery Protocol (LLDP) Agent
with Data Center Bridging (DCB) for Intel(R) Network Connections
'lldpad' plus the configuration tools 'dcbtool' and 'lldptool'.

%package -n %{libname}
Summary:        Link Layer Discovery Protocol (LLDP) libraries
Group:          System/Libraries

%description -n %{libname}
This package contains the Link Layer Discovery Protocol (LLDP) libraries

%package devel
Summary:        Link Layer Discovery Protocol (LLDP) Agent
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}
Provides:       dcbd-devel = %{version}
Obsoletes:      dcbd-devel < %{version}
Provides:       lldpad-devel = %{version}
Obsoletes:      lldpad-devel < %{version}

%description devel
This package contains the Link Layer Discovery Protocol (LLDP) Agent
with Data Center Bridging (DCB) for Intel(R) Network Connections
'lldpad' plus the configuration tools 'dcbtool' and 'lldptool'.

%prep
%setup -n %{name}-v%{version}

%build
autoreconf -vi
%configure \
	--disable-static
make %{?_smp_mflags}

%check
make check %{?_smp_mflags}

%install
mkdir -p %{buildroot}/var/lib/lldpad
%makeinstall
# remove la archives
rm -rf %{buildroot}/%{_libdir}/*.la
ln -s service %{buildroot}%{_sbindir}/rclldpad

%post
%{fillup_only -n lldpad}
%service_add_post lldpad.service

%pre
%service_add_pre lldpad.service

%preun
%service_del_preun lldpad.service

%postun
%service_del_postun lldpad.service

%post -n %libname -p /sbin/ldconfig

%postun -n %libname -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc COPYING README ChangeLog
%dir /var/lib/lldpad
%{_unitdir}/*
%{_sbindir}/*
%{_mandir}/man3/*
%{_mandir}/man8/*
%config /etc/bash_completion.d/*

%files -n %libname
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so

%changelog
* Wed Sep  9 2020 lduncan@suse.com
- Update to version v1.0.1+64.29d12e584af1:
  * l2_packet: Guard ETH_P_LLDP define (bsc#1156545)
* Tue Aug  4 2020 hare@suse.de
- Update to version v1.0.1+63.f977e67 (bsc#1171284,bsc#1170745,bsc#1153520):
  * lldp/rx.c: Reset state machine variable in process_delete_info()
  * lldp: do not call 'assert' in rxProcessFrame()
  * ecp: allow for failure to create
  * lldp_mand: retrieve permanent mac address in get_mac()
  * lldp_util: use netlink to fetch mac address
  * lldp_util: drop get_macstr()
  * linux/if_link.h: Update and add bonding netlink definitions
* Thu Jan 10 2019 hare@suse.de
- Update to git commit cb81e9541b5 (FATE#326034,bug#1104011)
  * 8021qaz: Remove unused variable
  * 8021qaz: Honor willing value from config file
  * lldpad: Support DSCP selectors in APP TLV's
  * Fix application tlv display
  * basman_clif: print the OID properly
  * ecp22: deinit l2_packet_data before freeing ecp22
  * DCB set state operation return value check
  * memleak on received TLVs from modules
  * Use interface index instead of name in libconfig
  * Fix 'is_valid_mac' to include mcast mac address
  * lldpad: Fix segfault in lldptool
  * Fixup disabling PG
  + open-lldp-v1.0.1+56.cb81e95.tar.xz
- Remove superseded files
  - open-lldp-1.0.1.tar.gz
  - open-lldp-git-update.patch.bz2
  - open-lldp-gcc5.patch
  - 0001-l2_linux_packet-correctly-process-return-value-of-ge.patch
  - 0002-lldpad-Only-set-Tx-adminStatus-if-interface-is-not-m.patch
* Mon Dec 11 2017 dimstar@opensuse.org
- Fix calling of fillup_only: it knows no -i parameter.
* Tue Feb 28 2017 dimstar@opensuse.org
- Don't use full URL as source, as the tarball does not exist at
  that location.
* Sat Feb 18 2017 kukuk@suse.com
- Remove obsolete insserv calls
* Mon Aug  3 2015 hare@suse.de
- Update to v1.0.1 (FATE#318849)
  * vpd22 updates
  * Include vpdtool
  * Support for OUI infrastructure in vpd22
  * Support for OUI infrastructure in vpdtool
  * Support for Cisco-specific OUI extensions in vpd22
  * Add vpdtool manpage
  * Add open-lldp-1.0.1.tar.gz
  * Remove open-lldp-0.9.46.tar.gz
  * Patches merged with upstream
  * Remove 0001-lldpad-print-verbose-error-messages.patch
  * Remove 0002-Move-to-libnl3.patch
- Update to latest git version
  * Automake fixes
  * Fix DCBX event generation from lldpad
  * Make TTL TLV configurable
  * Update open-lldp-git-update.patch.bz2
- Correctly process return value in get_perm_hwaddr (bsc#929171)
  * Add 0001-l2_linux_packet-correctly-process-return-value-of-ge.patch
- lldpad: Only set Tx adminStatus if interface is not managed
  (bsc#929171)
  * Add 0002-lldpad-Only-set-Tx-adminStatus-if-interface-is-not-m.patch
* Mon Mar 23 2015 crrodriguez@opensuse.org
- Fix build with gcc5 (open-lldp-gcc5.patch)
  * do not use -Werror
  * Use -fgnu89-inline as the code relies on the old semantics
* Wed May 21 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Wed May 14 2014 hare@suse.de
- Update to latest git version:
  * Include upstream version of VEPA migration issue (bnc#866282)
  * evb 22 test cases
  * vdp22 fixes
  * error message fixes
  * Fix interop issues with Juniper switches
- Fixup error messages in lldpad
  * Add 0001-lldpad-print-verbose-error-messages.patch
- Move to libnl3
  * Add 0002-Move-to-libnl3.patch
* Fri Mar 21 2014 hare@suse.de
- Fix VEPA migration issue (bnc#866282)
- Remove mkinitrd support
- Use bzip2 for open-lldp-git-update.patch
  * Add open-lldp-git-update.patch.bz2
  * Delete open-lldp-git-update.patch
* Tue Nov 19 2013 hare@suse.de
- Update to latest git version:
  * VPD22 support
  * Netlink fixes
* Thu Oct 10 2013 tchvatal@suse.com
- Provide and Obsolete old devel packages to avoid collisons.
- More whitespace cleanup.
* Fri Sep 13 2013 hare@suse.de
- Rename to open-lldp to be compliant with upstream
- Update to latest git version
  * Systemd integration
  * EVB fixes
- Update mkinitrd scriptlets
- Remove 'llpdad-makefile-fixup', merged with upstream
- Remove 'mkinitrd-stop.sh'
- Add open-lldp-git-update.patch to build properly
* Thu Aug  1 2013 tchvatal@suse.com
- Bump to 0.9.46 new upstream url found from fedora pkg:
  * Add IEEE802.1Qbg EVB module support
  * add and improve test code evbest/nltest
  * 8021qaz fix to work with hardware that does not support CEE DCBX
  * support lldpad running on bonded interfaces
  * pretty print support for VDP
  * new -p option to display lldpad process identifier
  * generate shared library liblldp_clif for applications to use
  * Add vdptest program
  * various link event fixes
  * Support for multiple agent types Nearest non-TPMR, Nearest customer bridge,
  and Nearest Bridge (always supported).
  * New man pages for VDP, EVB, and MED have been added.
  * DCBX improvements to remap DCB attributes when the host has less traffic
  classes then the peer.
  * Support to parse 802.1AB Organizationally Specific TLVs, Cisco Specific TLVs
  and the LLINK attributes of the DCBX CEE TLVs.
  * Support to reconfigure and set the MSAP subtype.
  * Additional gcc warnings turned on and miscellaneous fixes.
  * New client interface (abstract sockets) to support initrd stage
  * IEEE 802.1Qaz support has been added
  * EVB support has been added
  * Add iSCSI TLV support
  * Numerous bug fixes and code cleanup
  * Reworked netlink event handling to be more robust and handle dropped nlmsgs.
  * DCBx puts netdevice into linkmode until dcbx negotiation complete
- Remove obsolete patches, applied upstream/done differently by upstream:
  * lldpad-0.9.32-compile-fixes
  * lldpad-0.9.32-fix-buffer-overflow
  * lldpad-0.9.32-fix-error-in-pgid-construction
  * lldpad-0.9.32-fix-lldptool-segfault
  * lldpad-0.9.32-fix-race-condition
- Rebase patch to apply on current version:
  * lldpad-makefile-fixup
- Use unit file instead of init file to move under systemd
* Tue Jul 23 2013 ohering@suse.de
- Remove usage of absolute paths in mkinitrd scripts
- Add Requires(post/postun) to spec file
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Jul  6 2010 hare@suse.de
- Port rpm from SLES11 SP1.
* Fri May  7 2010 hare@suse.de
- Remove 'fix link flap' patch (bnc#603580)
* Mon Apr 26 2010 hare@suse.de
- Patches from bnc#599107:
  * fix race condition by opening client socket earlier
  * fix error in construction of the Priority Group TLV
  * fix link flap
  * fix segfault when handling lldptool arguments
  * fix buffer overflow in lldp-med inventory string
* Fri Mar 26 2010 kukuk@suse.de
- Fix requires of -devel subpackage
* Wed Mar 24 2010 hare@suse.de
- Fixup mkinitrd setup script to always create /var/lib/lldpad
* Tue Mar 23 2010 hare@suse.de
- Obsolete dcbd by lldpad version 0.9.32 (bnc#590487)
